import { Request, Response } from 'express';
import { PrismaClient } from '@prisma/client';

const prisma = new PrismaClient();

export const searchLocalJobOffers = async (req: Request, res: Response) => {
  try {
    const page = parseInt(req.query.page as string) || 1;
    const limit = parseInt(req.query.limit as string) || 10;
    const skip = (page - 1) * limit;
    const take = limit;
    const sortBy = req.query.sortBy as string || 'publicationDate';
    const sortOrder = req.query.sortOrder as string || 'desc';
    const keyword = req.query.keyword as string;
    const location = req.query.location as string;
    const contractType = req.query.contractType as string;

    console.log('Keyword:', keyword);
    console.log('Location:', location);

    const where: any = {};
    if (keyword) {
      where.OR = [
        { title: { contains: keyword, mode: 'insensitive' } },
        { description: { contains: keyword, mode: 'insensitive' } },
      ];
    }
    if (location) {
      where.AND = [
        ...(where.AND || []),
        {
          OR: [
            { locationLabel: { contains: location, mode: 'insensitive' } },
            { postalCode: { contains: location, mode: 'insensitive' } },
            { cityName: { contains: location, mode: 'insensitive' } },
            { departmentCode: { contains: location, mode: 'insensitive' } },
          ],
        },
      ];
    }
    if (contractType) {
      where.AND = [
        ...(where.AND || []),
        { contractType: contractType },
      ];
    }

    const orderBy: any = {};
    if (sortBy) {
      orderBy[sortBy] = sortOrder === 'asc' ? 'asc' : 'desc';
    } else {
      orderBy.publicationDate = 'desc'; // Tri par défaut
    }

    const jobs = await prisma.jobOffer.findMany({
      skip,
      take,
      where,
      orderBy,
    });

    const total = await prisma.jobOffer.count({ where });

    res.status(200).json({
      jobs,
      total,
      page,
      limit,
    });
  } catch (error) {
    console.error('Error searching job offers:', error);
    res.status(500).json({ error: 'Failed to search job offers' });
  }
};